@@ -8,7 +8,7 @@ use Modern::Perl qw(2015); # require 5.20.0
 ## use critic (Modules::RequireExplicitPackage)
 
 package Container::Buildah::Stage;
-$Container::Buildah::Stage::VERSION = '0.2.1';
+$Container::Buildah::Stage::VERSION = '0.3.0';
 use autodie;
 use Carp qw(croak confess);
 use Cwd;
@@ -219,11 +219,16 @@ sub add
 	# process parameters
 	my ($extract, @args) = process_params({name => 'add',
 		extract => [qw(dest)],
-		arg_init => [qw(--add-history)],
-		arg_flag => [qw(quiet)],
+		arg_flag => [qw(add-history quiet)],
 		arg_str => [qw(chown)]
 	}, $params);
 
+	# insert --add-history if corresponding global option set
+	# (buildah also does this by $ENV{BUILDAH_HISTORY}='true')
+	if (Container::Buildah->get_config(qw(opts add-history)) // 0) {
+		unshift @args, "--add-history";
+	}
+
 	# get special parameter dest if it exists
 	my $dest = $extract->{dest};
 
@@ -277,7 +282,7 @@ sub config
 
 	# process parameters
 	my ($extract, @args) = process_params({name => 'config',
-		arg_init => [qw(--add-history)],
+		arg_flag => [qw(add-history)],
 		arg_str => [qw(arch author cmd comment created-by domainname healthcheck healthcheck-interval
 			healthcheck-retries healthcheck-start-period healthcheck-timeout history-comment hostname
 			os shell stop-signal user workingdir)],
@@ -285,6 +290,12 @@ sub config
 		arg_list => [qw(entrypoint)],
 	}, $params);
 
+	# insert --add-history if corresponding global option set
+	# (buildah also does this by $ENV{BUILDAH_HISTORY}='true')
+	if (Container::Buildah->get_config(qw(opts add-history)) // 0) {
+		unshift @args, "--add-history";
+	}
+
 	# run command
 	my $cb = Container::Buildah->instance();
 	$cb->buildah("config", @args, $self->container_name);
@@ -306,11 +317,16 @@ sub copy
 	# process parameters
 	my ($extract, @args) = process_params({name => 'copy',
 		extract => [qw(dest)],
-		arg_init => [qw(--add-history)],
-		arg_flag => [qw(quiet)],
+		arg_flag => [qw(add-history quiet)],
 		arg_str => [qw(chown)]
 	}, $params);
 
+	# insert --add-history if corresponding global option set
+	# (buildah also does this by $ENV{BUILDAH_HISTORY}='true')
+	if (Container::Buildah->get_config(qw(opts add-history)) // 0) {
+		unshift @args, "--add-history";
+	}
+
 	# get special parameter dest if it exists
 	my $dest = $extract->{dest};
 
@@ -337,13 +353,18 @@ sub run
 
 	# process parameters
 	my ($extract, @args) = process_params({name => 'run',
-		arg_init => ['--add-history'],
-		arg_flag => [qw(no-pivot terminal)],
+		arg_flag => [qw(add-history no-pivot terminal)],
 		arg_str => [qw(cni-config-dir cni-plugin-path hostname ipc isolation network pid runtime
 			user uts)],
 		arg_array => [qw(cap-add cap-drop mount runtime-flag security-opt volume)],
 	}, $params);
 
+	# insert --add-history if corresponding global option set
+	# (buildah also does this by $ENV{BUILDAH_HISTORY}='true')
+	if (Container::Buildah->get_config(qw(opts add-history)) // 0) {
+		unshift @args, "--add-history";
+	}
+
 	# loop through provided commands
 	# build outer array if only one command was provided
 	my @commands = ref $in_args[0] ? @in_args : [@in_args];
@@ -647,7 +668,7 @@ Container::Buildah::Stage - object used by Container::Buildah to track a stage o
 
 =head1 VERSION
 
-version 0.2.1
+version 0.3.0
 
 =head1 SYNOPSIS
 
@@ -725,6 +746,8 @@ Please report bugs via GitHub at L<https://github.com/ikluft/Container-Buildah/i
 
 Patches and enhancements may be submitted via a pull request at L<https://github.com/ikluft/Container-Buildah/pulls>
 
+Containers can only be run with a Linux kernel revision 2.8 or newer.
+
 =head1 AUTHOR
 
 Ian Kluft <https://github.com/ikluft>
